@@ -1,16 +1,15 @@
+mod file;
 mod genome;
 mod ioutils;
-mod file;
 
+pub mod algorithm;
 pub mod property;
 pub mod record;
-pub mod algorithm;
 
-pub use genome::{Genome, ChrRef};
 pub use file::LineRecordStreamExt;
+pub use genome::{ChrRef, Genome};
 
-pub mod prelude {
-}
+pub mod prelude {}
 
 #[cfg(test)]
 mod test {
@@ -18,6 +17,7 @@ mod test {
 
     #[test]
     fn test_genome_storage() {
+        Genome::clear_genome_definition();
         let id = Genome::query_chr("chr1").get_id_or_update();
         assert_eq!(id, 0);
         assert_eq!(Genome::query_chr("chr1").id(), Some(0));
